@@ -49,6 +49,30 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateBasicModeration(self, request):
+        """接口说明：
+        启动终端审核功能，完成房间内的音频审核。
+
+        :param request: Request instance for CreateBasicModeration.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.CreateBasicModerationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.CreateBasicModerationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateBasicModeration", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateBasicModerationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateCloudRecording(self, request):
         """接口说明：
         启动云端录制功能，完成房间内的音视频录制，并上传到指定的云存储。您可以通过此 API 接口把TRTC 房间中的每一路音视频流做单独的录制又或者多路视频画面合流混成一路。
@@ -106,6 +130,29 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteBasicModeration(self, request):
+        """成功开启审核任务后，可以使用此接口来停止任务。
+
+        :param request: Request instance for DeleteBasicModeration.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DeleteBasicModerationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DeleteBasicModerationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteBasicModeration", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteBasicModerationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteCloudRecording(self, request):
         """成功开启录制后，可以使用此接口来停止录制任务。停止录制成功后不代表文件全部传输完成，如果未完成后台将会继续上传文件，成功后通过事件回调通知客户文件全部传输完成状态。
 
@@ -1015,7 +1062,9 @@ class TrtcClient(AbstractClient):
 
 
     def StartAIConversation(self, request):
-        """启动一个任务，机器人将进入TRTC房间，与指定成员进行AI对话
+        """启动AI对话任务，AI通道机器人进入TRTC房间，与房间内指定的成员进行AI对话，适用于智能客服，AI口语教师等场景
+
+        TRTC AI对话功能内置语音转文本能力，同时提供通道服务，即客户可灵活指定第三方AI模型（LLM）服务和文本转音频（TTS)服务，更多[功能说明](https://cloud.tencent.com/document/product/647/108901)。
 
         :param request: Request instance for StartAIConversation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.StartAIConversationRequest`
@@ -1038,48 +1087,16 @@ class TrtcClient(AbstractClient):
 
 
     def StartAITranscription(self, request):
-        """这个接口调用后，后台会启动转录机器人，实时进行语音识别并下发字幕和转录消息。
+        """启动转录机器人，后台会通过机器人拉流进行实时进行语音识别并下发字幕和转录消息。
         转录机器人支持两种拉流方式，通过TranscriptionMode字段控制：
         - 拉取全房间的流。
         - 拉取特定用户的流。
 
-        服务端通过TRTC的自定义消息实时下发字幕和会议记录，CmdId固定是1。客户端只需监听自定义消息的回调即可，比如[c++回调](https://cloud.tencent.com/document/product/647/79637#4cd82f4edb24992a15a25187089e1565)。其他客户端比如安卓、Web等同样可在该链接处找到。
+        服务端通过TRTC的自定义消息实时下发字幕以及转录消息，CmdId固定是1。客户端只需监听自定义消息的回调即可，比如[c++回调](https://cloud.tencent.com/document/product/647/79637#4cd82f4edb24992a15a25187089e1565)。其他客户端比如安卓、Web等同样可在该链接处找到。
 
-        服务端实时下发的消息是JSON字符串，实时字幕具体格式如下：
-        `{
-            "type": "subtitle",
-            "userid": "xxx",
-            "text": "xxx",
-            "translation_text": "xxx",
-            "start_time": "00:00:02",
-            "end_time": "00:00:05"
-        }`
-        字段作用如下：
-        - type是subtitle，表示这是实时字幕消息。
-        - userid表示是哪个用户说的话。
-        - text是语音识别出的文本。
-        - translation_text是text翻译后的文本，如果不启用翻译，则是空字符串。
-        - start_time和end_time表示该字幕消息从任务开启后的开始和结束时间。
 
-        转录消息具体格式如下：
-        `{
-            "type": "transcription",
-            "userid": "xxx",
-            "text": "xxx",
-            "translation_text": "xx",
-            "start_time": "00:00:02",
-            "end_time": "00:00:05"
-        }`
-        字段作用如下：
-        - type是transcription，表示这是转录消息。
-        - 其余字段同实时字幕消息。
-
-        转录消息和实时字幕消息的区别是，转录消息是完整的一句话，实时字幕消息则是这一句话的中间阶段。
-        假如有一句完整的话，“今天天气怎么样？”，那么服务的下发消息的顺序可能是这样：
-        - 字幕消息，“今天”
-        - 字幕消息，“今天天气”
-        - 字幕消息，“今天天气怎么样”
-        - 转录消息，“今天天气怎么样？”
+        **注意：**
+        TranscriptionMode为0时，需要保证一个房间内只发起一个任务，如果发起多个任务，则机器人之间会相互订阅，除非主动停止任务，否则只有10小时后任务才会超时退出，这种情况下建议填写SessionId，保证后续重复发起的任务失败。
 
         :param request: Request instance for StartAITranscription.
         :type request: :class:`tencentcloud.trtc.v20190722.models.StartAITranscriptionRequest`
@@ -1427,22 +1444,20 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def SummarizeTranscription(self, request):
-        """接口不再支持
+    def UpdateAIConversation(self, request):
+        """更新AIConversation参数
 
-        对转录的文本进行总结。
-
-        :param request: Request instance for SummarizeTranscription.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.SummarizeTranscriptionRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.SummarizeTranscriptionResponse`
+        :param request: Request instance for UpdateAIConversation.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.UpdateAIConversationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.UpdateAIConversationResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("SummarizeTranscription", params, headers=headers)
+            body = self.call("UpdateAIConversation", params, headers=headers)
             response = json.loads(body)
-            model = models.SummarizeTranscriptionResponse()
+            model = models.UpdateAIConversationResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
@@ -1470,6 +1485,29 @@ class TrtcClient(AbstractClient):
             model = models.UpdatePublishCdnStreamResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateStreamIngest(self, request):
+        """更新输入在线媒体流任务的StreamUrl
+
+        :param request: Request instance for UpdateStreamIngest.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.UpdateStreamIngestRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.UpdateStreamIngestResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateStreamIngest", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateStreamIngestResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
